@@ -9,9 +9,9 @@ use byteorder::{BigEndian, WriteBytesExt};
 use crate::config::{Config, Delimiter, SeekRead};
 use crate::index::Indexed;
 use crate::select::{SelectColumns, Selection};
-use crate::serde::Deserialize;
 use crate::util;
 use crate::CliResult;
+use serde::Deserialize;
 
 static USAGE: &str = "
 Joins two sets of CSV data on the specified columns.
