@@ -61,6 +61,10 @@ Some usage examples:
   $ qsv py map c "int(col.a) + int(col['b'])"
   $ qsv py map c "int(col[0]) + int(col[1])"
 
+  Use Python f-strings to calculate using multiple columns (qty, fruit & unitcost) 
+    and format into a new column 'formatted'
+  $ qsv py map formatted "f'{qty} {fruit} cost ${(float(unitcost) * float(qty)):.2f}'"
+
   Strip and prefix cell values
   $ qsv py map prefixed "'clean_' + a.strip()"
 
@@ -170,7 +174,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         py_row.call_method1("_update_underlying_data", (row_data,))?;
 
         let result = py
-            .eval(&args.arg_script, Some(&globals), Some(&locals))
+            .eval(&args.arg_script, Some(globals), Some(locals))
             .map_err(|e| {
                 e.print_and_set_sys_last_vars(py);
                 "Evaluation of given expression failed with the above error!"
