@@ -132,6 +132,7 @@ impl Config {
         self
     }
 
+    #[allow(dead_code)]
     pub fn get_delimiter(&self) -> u8 {
         self.delimiter
     }
@@ -319,6 +320,10 @@ impl Config {
             .unwrap_or_else(|_| DEFAULT_RDR_BUFFER_CAPACITY.to_string());
         let rdr_buffer: usize = rdr_capacitys.parse().unwrap_or(DEFAULT_RDR_BUFFER_CAPACITY);
 
+        let rdr_comment: Option<u8> = env::var("QSV_COMMENT_CHAR")
+            .ok()
+            .map(|s| s.as_bytes().first().unwrap().to_owned());
+
         csv::ReaderBuilder::new()
             .flexible(self.flexible)
             .delimiter(self.delimiter)
@@ -327,6 +332,7 @@ impl Config {
             .quoting(self.quoting)
             .escape(self.escape)
             .buffer_capacity(rdr_buffer)
+            .comment(rdr_comment)
             .from_reader(rdr)
     }
 
